@@ -1,3 +1,4 @@
+import os
 import base64
 
 
@@ -12,3 +13,11 @@ def is_image_supported_ext(file_path: str) -> bool:
 
 def is_video_supported_ext(file_path: str) -> bool:
     return file_path.lower().endswith(('.mp4'))
+
+
+def get_basename(file_path: str) -> str:
+    """
+    e.g.) file.jpg -> file
+          path/to/file.jpg -> path/to/file
+    """
+    return os.path.splitext(file_path)[0]
